<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Keep contact list size</source>
        <translation>Kişi listesi boyutunu sakla</translation>
    </message>
    <message>
        <source>Hide scroll bar</source>
        <translation>Kaydırma çubuğunu gizle</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Ekstralar</translation>
    </message>
    <message>
        <source>Simple View</source>
        <translation>Basit Görünüm</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Hide window borders</source>
        <translation>Pencere kenarlarını gizle</translation>
    </message>
</context>
<context>
    <name>SimpleView</name>
    <message>
        <source>Simple view</source>
        <translation>Basti görünüm</translation>
    </message>
</context>
</TS>